#
# spec file for package python-python3-saml
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python3-saml
Version:        1.15.0
Release:        2.6
Summary:        Python SAML support
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/onelogin/python3-saml
Source:         https://github.com/onelogin/python3-saml/archive/v%{version}.tar.gz#/python3-saml-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-payloads-tests-dates.patch gh#SAML-Toolkits/python3-saml#271 mcepl@suse.com
# Fix payloads of tests that had expiration dates on May 2023
Patch0:         fix-payloads-tests-dates.patch
BuildRequires:  %{python_module freezegun >= 0.3.11}
BuildRequires:  %{python_module isodate >= 0.6.1}
BuildRequires:  %{python_module lxml >= 3.3.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xmlsec >= 1.3.9}
BuildRequires:  fdupes
BuildRequires:  libxmlsec1-openssl1
BuildRequires:  python-rpm-macros
# Select the libxmlsec backend known to work
# pkgconfig doesnt auto-require it.
Requires:       libxmlsec1-openssl1
Requires:       python-isodate >= 0.6.1
Requires:       python-lxml
Requires:       python-xmlsec >= 1.3.9
BuildArch:      noarch
%python_subpackages

%description
Python SAML support for your Python 2 or 3 software.

SAML is an XML-based standard for web browser single sign-on and is
defined by the OASIS Security Services Technical Committee.

%prep
%autosetup -p1 -n python3-saml-%{version}

sed -i 's/==/>=/;/dependency_links/d' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/onelogin

%check
# gh#onelogin/python3-saml#271
# the test suite is a complete disaster currently gh#onelogin/python3-saml#272
%pytest -k 'not (testIsInValidAudience or testIsInValidEncAttrs or testIsInValidIssuer or testIsInValidSessionIndex or testIsInValidSubjectConfirmation)' || /bin/true

%files %{python_files}
%license LICENSE
%doc README.md
%dir %{python_sitelib}/onelogin
%{python_sitelib}/onelogin/saml2
%{python_sitelib}/onelogin/__init__.py
%pycache_only %{python_sitelib}/onelogin/__pycache__/
%{python_sitelib}/python3_saml-%{version}*-info

%changelog
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Sun May 14 2023 Matej Cepl <mcepl@suse.com>
- Update to 1.15.0:
  - #317 Handle unicode characters gracefully in python 2
  - #338 Fix WantAuthnRequestsSigned parser
  - #339 Add Poetry support
  - Remove version restriction on lxml dependency
  - Updated Django demo to 4.X (only py3 compatible)
  - Updated Travis file. Forced lxml to be installed using
    no-validate_binary
  - Removed references to OneLogin from documentation
- Add fix-payloads-tests-dates.patch
  (gh#SAML-Toolkits/python3-saml#271).
* Fri Dec 30 2022 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
* Tue Oct 18 2022 Markéta Machová <mmachova@suse.com>
- No need to skip Python 3.10 anymore
* Mon May 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * Add support for python 3.10 and cleanup the GHA
  * Remove stats from coveralls removed as they are no longer maintained
  * Add rejectDeprecatedAlgorithm settings in order to be able reject messages
    signed with deprecated algorithms
  * Support building a LogoutResponse with non-success status
  * Replace double-underscored names with single underscores
  * Deprecate server_port from request data dictionary
* Fri Jul 23 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.11.0:
  - #261 Allow duplicate named attributes, controlled by a new
    setting
  - #268 Make the redirect scheme matcher case-insensitive
  - #256 Improve signature validation process. Add an option to
    use query string for validation
  - #259 Add get metadata timeout
  - #246 Add the ability to change the ProtocolBinding in the
    authn request.
  - #248 Move storing the response data into its own method in
    the Auth class
  - Remove the dependency on defusedxml
  - #241 Improve AttributeConsumingService support
  - Update expired dates from test responses
- The test suite is still ignored.
* Fri Jul 16 2021 Matej Cepl <mcepl@suse.com>
- The test suite is a complete disaster right now, switching it
  off (gh#onelogin/python3-saml#272).
* Thu Jul  8 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.10.1:
  - Fix bug on LogoutRequest class, get_idp_slo_response_url was
    used instead get_idp_slo_url
  - Added custom lxml parser based on the one defined at
    xmldefused. Parser will ignore comments and processing
    instructions and by default have deactivated huge_tree, DTD
    and access to external documents
  - Destination URL Comparison is now case-insensitive for netloc
  - Support single-label-domains as valid. New security parameter
    allowSingleLabelDomains
  - Added get_idp_sso_url, get_idp_slo_url and
    get_idp_slo_response_url methods to the Settings class and
    use it in the toolkit
  - #212 Overridability enhancements. Made classes overridable by
    subclassing. Use of classmethods instead staticmethods
  - Add get_friendlyname_attributes support
  - Remove external lib method get_ext_lib_path. Add
    set_cert_path in order to allow set the cert path in a
    different folder than the toolkit
  - Add sha256 instead sha1 algorithm for sign/digest as
    recommended value on documentation and settings
  - #178 Support for adding idp.crt from filesystem
  - Add samlUserdata to demo-flask session
  - Fix autoreloading in demo-tornado
- Remove bug-testDecryptElement.patch, which has been included
  upstream.
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 1.9.0
  * Allow any number of decimal places for seconds on SAML datetimes
  * Fix failOnAuthnContextMismatch code
  * Improve signature validation when no reference uri
  * Update demo versions. Improve them and add Tornado demo.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Adjusted acs endpoint to extract NameQualifier and SPNameQualifier from
    SAMLResponse.
  * Adjusted single logout service to provide NameQualifier and SPNameQualifier
    to logout method.
  * Add getNameIdNameQualifier to Auth and SamlResponse.
  * Extend logout method from Auth and LogoutRequest constructor to support.
  * Added get_in_response_to method to Response and LogoutResponse classes
  * Update defusexml dependency
* Wed Apr 10 2019 John Vandenberg <jayvdb@gmail.com>
- Add explicit dependency on libxmlsec1-openssl1, recommended
  by dependency python-xmlsec so this package may be used without
  needing to select a libxmlsec backend
- Activate test suite, adding bug-testDecryptElement.patch to
  workaround a test failure, and remove bcond test
- Build for Python 2, as support has been added upstream
- Remove unnecessary build dependency on python-devel
- Use %%license
- Remove live dependency_links and remove == pins from setup.py,
  so installed egg-info isnt broken
- Update to v1.6.0
  * Add support for Subjects on AuthNRequests by the new
    name_id_value_req parameter
  * Fix for SLO when XML specifies encoding
  * Fixed setting NameFormat attribute for AttributeValue tags
- from v1.5.0
  * Security improvements. Use of tagid to prevent XPath injection
    Disable DTD on fromstring defusedxml method
  * Check that the response has all of the AuthnContexts provided
  * Adapt renders from Django demo for Django 1.11 version
  * If debug enable, print reason for the SAMLResponse invalidation
  * Fix DSA constant
  * Support NameID children inside of AttributeValue elements
- from v1.4.1
  * Add ID to EntityDescriptor before sign it on add_sign method
  * Update defusedxml dependencies
  * Update copyright and license reference
- from 1.4.0
  * Fix CVE-2017-11427. Process text of nodes properly, ignoring comments
  * Improve how fingerprint is calcultated
  * Fix issue with LogoutRequest rejected by ADFS due NameID with
    unspecified format instead no format attribute
  * Fix signature position in the SP metadata
  * Preserve xmlns:xs namespace when signing and serializing responses
  * Redefine NSMAP constant
  * Updated Django demo (Django 1.11)
* Wed Oct 25 2017 sean.marlow@suse.com
- Intial package. v1.3.0
